@@ -114,7 +114,7 @@ inline void IUTEST_ATTRIBUTE_UNUSED_ InitGoogleMock(int* argc, wchar_t** argv)
 }
 #endif
 
-}
+}	// end of namespace iutest
 
 #ifndef GMOCK_INCLUDE_GMOCK_GMOCK_H_
 
@@ -279,6 +279,13 @@ namespace tr1
 #define IUTEST_HAS_REGEX			GTEST_USES_POSIX_RE
 #define IUTEST_HAS_SEH				GTEST_HAS_SEH
 
+#ifndef IUTEST_CXX_OVERRIDE
+#  define IUTEST_CXX_OVERRIDE
+#endif
+#ifndef IUTEST_CXX_DEFAULT_FUNCTION
+#  define IUTEST_CXX_DEFAULT_FUNCTION	{}
+#endif
+
 #include "switch/iutest_switch_port.hpp"
 #include "switch/iutest_switch_core.hpp"
 
@@ -303,8 +310,8 @@ namespace tr1
 #include "switch/iutest_switch_cmphelper.hpp"
 
 #ifndef IUTEST_STATIC_ASSERT_MSG
-#  define IUTEST_STATIC_ASSERT_MSG(B, Msg)	\
-	typedef ::testing::iusupport::StaticAssertionTest< sizeof(::testing::iusupport::StaticAssertionFailure< (bool)B >) > IUTEST_PP_CAT(iutest_static_assert_typedef_, __LINE__)
+#  define IUTEST_STATIC_ASSERT_MSG(B, Msg)	typedef ::testing::iusupport::StaticAssertionTest<	\
+		sizeof(::testing::iusupport::StaticAssertionFailure< (bool)B >) > IUTEST_PP_CAT(iutest_static_assert_typedef_, __LINE__)	// NOLINT
 #endif
 
 #ifndef IUTEST_STATIC_ASSERT
@@ -356,16 +363,27 @@ inline void IUTEST_ATTRIBUTE_UNUSED_ InitIrisUnitTest(int* pargc, const wchar_t*
 // tuple
 namespace tuples
 {
+#if GTEST_HAS_STD_TUPLE_
+	using ::std::tuple;
+	using ::std::tuple_size;
+	using ::std::tuple_element;
+	using ::std::make_tuple;
+	using ::std::get;
+#else
 	using ::std::tr1::tuple;
 	using ::std::tr1::tuple_size;
 	using ::std::tr1::tuple_element;
 	using ::std::tr1::make_tuple;
 	using ::std::tr1::get;
-}
+#endif
+}	// end of namespace tuples
 
+#if GTEST_VER < 0x01080000
 using tuples::tuple;
 using tuples::tuple_size;
 using tuples::tuple_element;
+#endif
+
 using tuples::make_tuple;
 using tuples::get;
 
