@@ -6,7 +6,7 @@
  *
  * @author		t.shirayanagi
  * @par			copyright
- * Copyright (C) 2011-2014, Takazumi Shirayanagi\n
+ * Copyright (C) 2011-2015, Takazumi Shirayanagi\n
  * This software is released under the new BSD License,
  * see LICENSE
 */
@@ -17,10 +17,8 @@
 
 //======================================================================
 // include
-#include "../iutest_defs.hpp"
 
 #if IUTEST_HAS_EXCEPTIONS
-#include "iutest_string.hpp"
 #include <exception>
 //#include <stdexcept>	// std::invalid_argment
 
@@ -35,7 +33,7 @@ namespace detail
 */
 inline ::std::string FormatCxxException(const char* description)
 {
-	iuStringStream::type strm;
+	iu_stringstream strm;
 	if( description != NULL )
 	{
 		strm << "C++ exception with description \"" << description << "\"";
@@ -63,15 +61,15 @@ namespace detail
 class seh_exception : public ::std::exception
 {
 public:
-	seh_exception(const char *const& _What) : ::std::exception(_What) {}
 	seh_exception(void) : ::std::exception() {}
+	explicit seh_exception(const char *const& _What) : ::std::exception(_What) {}
 public:
 	static void translator(DWORD code, _EXCEPTION_POINTERS* ep)
 	{
 		IUTEST_UNUSED_VAR(ep);
-		iuStringStream::type strm;
+		iu_stringstream strm;
 #if IUTEST_HAS_STRINGSTREAM || IUTEST_HAS_STRSTREAM
-		strm << "SEH exception with code 0x" << ::std::setbase(16) << code << ::std::setbase(10);
+		strm << "SEH exception with code 0x" << ::std::setbase(16) << code;
 #else
 		strm << "SEH exception with code " << code;
 #endif
