@@ -87,8 +87,7 @@ inline void iuOptionMessage::ShowHelp(void)
 		"    Copyright (c) 2011-2015, Takazumi-Shirayanagi\n"
 		"\n"
 		"    This software is released under the new BSD License, see LICENSE\n"
-		"\n"
-		;
+		"\n";
 	detail::iuConsole::color_output(detail::iuConsole::cyan, readme);
 }
 
@@ -99,108 +98,110 @@ inline void iuOptionMessage::ShowVersion(void)
 }
 
 /** @private */
-#define SHOW_MACRO(macro)	detail::iuConsole::output("#define %s  %s\n", #macro, IUTEST_PP_TOSTRING(macro))
+#define IIUT_SHOW_MACRO(macro)	detail::iuConsole::output("#define %s  %s\n", #macro, IUTEST_PP_TOSTRING(macro))
 
 inline void iuOptionMessage::ShowFeature(void)
 {
-	SHOW_MACRO(IUTEST_HAS_ANY_PARAM_TEST);
-	SHOW_MACRO(IUTEST_HAS_ASSERTION_RETURN);
-	SHOW_MACRO(IUTEST_HAS_CHAR16_T);
-	SHOW_MACRO(IUTEST_HAS_CHAR32_T);
-	SHOW_MACRO(IUTEST_HAS_COMBINE);
-	SHOW_MACRO(IUTEST_HAS_CONCAT);
-	SHOW_MACRO(IUTEST_HAS_EXCEPTIONS);
-	SHOW_MACRO(IUTEST_HAS_GENRAND);
-	SHOW_MACRO(IUTEST_HAS_IF_EXISTS);
-	SHOW_MACRO(IUTEST_HAS_IGNORE_TEST);
-	SHOW_MACRO(IUTEST_HAS_INITIALIZER_LIST);
-	SHOW_MACRO(IUTEST_HAS_LIB);
-	SHOW_MACRO(IUTEST_HAS_MATCHERS);
-	SHOW_MACRO(IUTEST_HAS_MATCHER_ALLOF_AND_ANYOF);
-	SHOW_MACRO(IUTEST_HAS_MATCHER_ELEMENTSARE);
-	SHOW_MACRO(IUTEST_HAS_MATCHER_REGEX);
-	SHOW_MACRO(IUTEST_HAS_MINIDUMP);
-	SHOW_MACRO(IUTEST_HAS_NULLPTR);
-	SHOW_MACRO(IUTEST_HAS_PACKAGE);
-	SHOW_MACRO(IUTEST_HAS_PAIRWISE);
-	SHOW_MACRO(IUTEST_HAS_PARAM_METHOD_TEST);
-	SHOW_MACRO(IUTEST_HAS_PARAM_TEST);
-	SHOW_MACRO(IUTEST_HAS_PEEP);
-	SHOW_MACRO(IUTEST_HAS_PEEP_CLASS);
-	SHOW_MACRO(IUTEST_HAS_PEEP_FUNC);
-	SHOW_MACRO(IUTEST_HAS_PEEP_STATIC_FUNC);
-	SHOW_MACRO(IUTEST_HAS_PRINT_TO);
-	SHOW_MACRO(IUTEST_HAS_RANDOMVALUES);
-	SHOW_MACRO(IUTEST_HAS_REGEX);
-	SHOW_MACRO(IUTEST_HAS_REPORT_SKIPPED);
-	SHOW_MACRO(IUTEST_HAS_SEH);
-	SHOW_MACRO(IUTEST_HAS_SOCKET);
-	SHOW_MACRO(IUTEST_HAS_SPI_LAMBDA_SUPPORT);
-	SHOW_MACRO(IUTEST_HAS_STATIC_ASSERT);
-	SHOW_MACRO(IUTEST_HAS_STATIC_ASSERT_TYPEEQ);
-	SHOW_MACRO(IUTEST_HAS_STREAM_RESULT);
-	SHOW_MACRO(IUTEST_HAS_STREAMCAPTURE);
-	SHOW_MACRO(IUTEST_HAS_TESTNAME_ALIAS);
-	SHOW_MACRO(IUTEST_HAS_TESTNAME_ALIAS_JP);
-	SHOW_MACRO(IUTEST_HAS_TUPLE);
-	SHOW_MACRO(IUTEST_HAS_TYPED_TEST);
-	SHOW_MACRO(IUTEST_HAS_TYPED_TEST_P);
-	SHOW_MACRO(IUTEST_HAS_VALUESGEN);
-	SHOW_MACRO(IUTEST_HAS_VARIADIC_COMBINE);
-	SHOW_MACRO(IUTEST_HAS_VARIADIC_PAIRWISE);
-	SHOW_MACRO(IUTEST_HAS_VARIADIC_VALUES);
-	SHOW_MACRO(IUTEST_CHECK_STRICT);
-	SHOW_MACRO(IUTEST_PLATFORM);
-	SHOW_MACRO(IUTEST_USE_THROW_ON_ASSERTION_FAILURE);
+	IIUT_SHOW_MACRO(IUTEST_HAS_ANY_PARAM_TEST);
+	IIUT_SHOW_MACRO(IUTEST_HAS_ASSERTION_RETURN);
+	IIUT_SHOW_MACRO(IUTEST_HAS_CHAR16_T);
+	IIUT_SHOW_MACRO(IUTEST_HAS_CHAR32_T);
+	IIUT_SHOW_MACRO(IUTEST_HAS_COMBINE);
+	IIUT_SHOW_MACRO(IUTEST_HAS_CONCAT);
+	IIUT_SHOW_MACRO(IUTEST_HAS_EXCEPTIONS);
+	IIUT_SHOW_MACRO(IUTEST_HAS_GENRAND);
+	IIUT_SHOW_MACRO(IUTEST_HAS_IF_EXISTS);
+	IIUT_SHOW_MACRO(IUTEST_HAS_IGNORE_TEST);
+	IIUT_SHOW_MACRO(IUTEST_HAS_INITIALIZER_LIST);
+	IIUT_SHOW_MACRO(IUTEST_HAS_LIB);
+	IIUT_SHOW_MACRO(IUTEST_HAS_MATCHERS);
+	IIUT_SHOW_MACRO(IUTEST_HAS_MATCHER_ALLOF_AND_ANYOF);
+	IIUT_SHOW_MACRO(IUTEST_HAS_MATCHER_ELEMENTSARE);
+	IIUT_SHOW_MACRO(IUTEST_HAS_MATCHER_REGEX);
+	IIUT_SHOW_MACRO(IUTEST_HAS_MINIDUMP);
+	IIUT_SHOW_MACRO(IUTEST_HAS_NULLPTR);
+	IIUT_SHOW_MACRO(IUTEST_HAS_PACKAGE);
+	IIUT_SHOW_MACRO(IUTEST_HAS_PAIRWISE);
+	IIUT_SHOW_MACRO(IUTEST_HAS_PARAM_METHOD_TEST);
+	IIUT_SHOW_MACRO(IUTEST_HAS_PARAM_TEST);
+	IIUT_SHOW_MACRO(IUTEST_HAS_PEEP);
+	IIUT_SHOW_MACRO(IUTEST_HAS_PEEP_CLASS);
+	IIUT_SHOW_MACRO(IUTEST_HAS_PEEP_FUNC);
+	IIUT_SHOW_MACRO(IUTEST_HAS_PEEP_STATIC_FUNC);
+	IIUT_SHOW_MACRO(IUTEST_HAS_PRINT_TO);
+	IIUT_SHOW_MACRO(IUTEST_HAS_RANDOMVALUES);
+	IIUT_SHOW_MACRO(IUTEST_HAS_REGEX);
+	IIUT_SHOW_MACRO(IUTEST_HAS_REPORT_SKIPPED);
+	IIUT_SHOW_MACRO(IUTEST_HAS_SEH);
+	IIUT_SHOW_MACRO(IUTEST_HAS_SOCKET);
+	IIUT_SHOW_MACRO(IUTEST_HAS_SPI_LAMBDA_SUPPORT);
+	IIUT_SHOW_MACRO(IUTEST_HAS_STATIC_ASSERT);
+	IIUT_SHOW_MACRO(IUTEST_HAS_STATIC_ASSERT_TYPEEQ);
+	IIUT_SHOW_MACRO(IUTEST_HAS_STREAM_RESULT);
+	IIUT_SHOW_MACRO(IUTEST_HAS_STREAMCAPTURE);
+	IIUT_SHOW_MACRO(IUTEST_HAS_TESTNAME_ALIAS);
+	IIUT_SHOW_MACRO(IUTEST_HAS_TESTNAME_ALIAS_JP);
+	IIUT_SHOW_MACRO(IUTEST_HAS_TUPLE);
+	IIUT_SHOW_MACRO(IUTEST_HAS_TYPED_TEST);
+	IIUT_SHOW_MACRO(IUTEST_HAS_TYPED_TEST_P);
+	IIUT_SHOW_MACRO(IUTEST_HAS_VALUESGEN);
+	IIUT_SHOW_MACRO(IUTEST_HAS_VARIADIC_COMBINE);
+	IIUT_SHOW_MACRO(IUTEST_HAS_VARIADIC_PAIRWISE);
+	IIUT_SHOW_MACRO(IUTEST_HAS_VARIADIC_VALUES);
+	IIUT_SHOW_MACRO(IUTEST_CHECK_STRICT);
+	IIUT_SHOW_MACRO(IUTEST_PLATFORM);
+	IIUT_SHOW_MACRO(IUTEST_USE_THROW_ON_ASSERTION_FAILURE);
 }
 
 inline void iuOptionMessage::ShowSpec(void)
 {
-	SHOW_MACRO(IUTEST_HAS_ANALYSIS_ASSUME);
-	SHOW_MACRO(IUTEST_HAS_CHAR16_T);
-	SHOW_MACRO(IUTEST_HAS_CHAR32_T);
-	SHOW_MACRO(IUTEST_HAS_CLOCK);
-	SHOW_MACRO(IUTEST_HAS_CONSTEXPR);
-	SHOW_MACRO(IUTEST_HAS_COUNTER_MACRO);
-	SHOW_MACRO(IUTEST_HAS_CTIME);
-	SHOW_MACRO(IUTEST_HAS_CXX_HDR_CHRONO);
-	SHOW_MACRO(IUTEST_HAS_CXX_HDR_RANDOM);
-	SHOW_MACRO(IUTEST_HAS_CXX_HDR_REGEX);
-	SHOW_MACRO(IUTEST_HAS_CXX11);
-	SHOW_MACRO(IUTEST_HAS_DELETED_FUNCTIONS);
-	SHOW_MACRO(IUTEST_HAS_EXCEPTIONS);
-	SHOW_MACRO(IUTEST_HAS_EXPLICIT_CONVERSION);
-	SHOW_MACRO(IUTEST_HAS_EXTERN_TEMPLATE);
-	SHOW_MACRO(IUTEST_HAS_GETTIMEOFDAY);
-	SHOW_MACRO(IUTEST_HAS_HDR_CXXABI);
-	SHOW_MACRO(IUTEST_HAS_HDR_SYSTIME);
-	SHOW_MACRO(IUTEST_HAS_IF_EXISTS);
-	SHOW_MACRO(IUTEST_HAS_INITIALIZER_LIST);
-	SHOW_MACRO(IUTEST_HAS_LAMBDA);
-	SHOW_MACRO(IUTEST_HAS_NOEXCEPT);
-	SHOW_MACRO(IUTEST_HAS_NULLPTR);
-	SHOW_MACRO(IUTEST_HAS_OVERRIDE_AND_FINAL);
-	SHOW_MACRO(IUTEST_HAS_RTTI);
-	SHOW_MACRO(IUTEST_HAS_RVALUE_REFS);
-	SHOW_MACRO(IUTEST_HAS_SEH);
-	SHOW_MACRO(IUTEST_HAS_STD_EMPLACE);
-	SHOW_MACRO(IUTEST_HAS_STRINGSTREAM);
-	SHOW_MACRO(IUTEST_HAS_STRONG_ENUMS);
-	SHOW_MACRO(IUTEST_HAS_STRSTREAM);
-	SHOW_MACRO(IUTEST_HAS_VARIADIC_TEMPLATES);
-	SHOW_MACRO(IUTEST_HAS_VARIADIC_TEMPLATE_TEMPLATES);
+	IIUT_SHOW_MACRO(IUTEST_HAS_ANALYSIS_ASSUME);
+	IIUT_SHOW_MACRO(IUTEST_HAS_CHAR16_T);
+	IIUT_SHOW_MACRO(IUTEST_HAS_CHAR32_T);
+	IIUT_SHOW_MACRO(IUTEST_HAS_CLOCK);
+	IIUT_SHOW_MACRO(IUTEST_HAS_CONSTEXPR);
+	IIUT_SHOW_MACRO(IUTEST_HAS_COUNTER_MACRO);
+	IIUT_SHOW_MACRO(IUTEST_HAS_CTIME);
+	IIUT_SHOW_MACRO(IUTEST_HAS_CXX_HDR_CHRONO);
+	IIUT_SHOW_MACRO(IUTEST_HAS_CXX_HDR_RANDOM);
+	IIUT_SHOW_MACRO(IUTEST_HAS_CXX_HDR_REGEX);
+	IIUT_SHOW_MACRO(IUTEST_HAS_CXX11);
+	IIUT_SHOW_MACRO(IUTEST_HAS_DELETED_FUNCTIONS);
+	IIUT_SHOW_MACRO(IUTEST_HAS_EXCEPTIONS);
+	IIUT_SHOW_MACRO(IUTEST_HAS_EXPLICIT_CONVERSION);
+	IIUT_SHOW_MACRO(IUTEST_HAS_EXTERN_TEMPLATE);
+	IIUT_SHOW_MACRO(IUTEST_HAS_GETTIMEOFDAY);
+	IIUT_SHOW_MACRO(IUTEST_HAS_HDR_CXXABI);
+	IIUT_SHOW_MACRO(IUTEST_HAS_HDR_SYSTIME);
+	IIUT_SHOW_MACRO(IUTEST_HAS_IF_EXISTS);
+	IIUT_SHOW_MACRO(IUTEST_HAS_INITIALIZER_LIST);
+	IIUT_SHOW_MACRO(IUTEST_HAS_LAMBDA);
+	IIUT_SHOW_MACRO(IUTEST_HAS_NOEXCEPT);
+	IIUT_SHOW_MACRO(IUTEST_HAS_NULLPTR);
+	IIUT_SHOW_MACRO(IUTEST_HAS_OVERRIDE_AND_FINAL);
+	IIUT_SHOW_MACRO(IUTEST_HAS_RTTI);
+	IIUT_SHOW_MACRO(IUTEST_HAS_RVALUE_REFS);
+	IIUT_SHOW_MACRO(IUTEST_HAS_SEH);
+	IIUT_SHOW_MACRO(IUTEST_HAS_STD_BEGIN_END);
+	IIUT_SHOW_MACRO(IUTEST_HAS_STD_DECLVAL);
+	IIUT_SHOW_MACRO(IUTEST_HAS_STD_EMPLACE);
+	IIUT_SHOW_MACRO(IUTEST_HAS_STRINGSTREAM);
+	IIUT_SHOW_MACRO(IUTEST_HAS_STRONG_ENUMS);
+	IIUT_SHOW_MACRO(IUTEST_HAS_STRSTREAM);
+	IIUT_SHOW_MACRO(IUTEST_HAS_VARIADIC_TEMPLATES);
+	IIUT_SHOW_MACRO(IUTEST_HAS_VARIADIC_TEMPLATE_TEMPLATES);
 
 #ifdef _MSC_FULL_VER
-	SHOW_MACRO(_MSC_FULL_VER);
+	IIUT_SHOW_MACRO(_MSC_FULL_VER);
 #endif
 #ifdef _LIBCPP_VERSION
-	SHOW_MACRO(_LIBCPP_VERSION);
+	IIUT_SHOW_MACRO(_LIBCPP_VERSION);
 #endif
 #ifdef __GLIBCXX__
-	SHOW_MACRO(__GLIBCXX__);
+	IIUT_SHOW_MACRO(__GLIBCXX__);
 #endif
 
-#undef SHOW_MACRO
+#undef IIUT_SHOW_MACRO
 }
 
 }	// end of namespace detail
