@@ -47,6 +47,7 @@ protected:
 	, m_id(id), m_disable_num(0)
 	, m_should_run_num(0)
 	, m_elapsedmsec(0)
+	, m_start_timestamp(0)
 	, m_disable(false)
 	{
 		if( detail::IsStringForwardMatching(testcase_name, "DISABLED_")
@@ -90,6 +91,8 @@ public:
 	int				reportable_test_run_skipped_count(void) const;
 	/** テストの実行ミリ秒 */
 	TimeInMillisec	elapsed_time(void)			const IUTEST_CXX_NOEXCEPT_SPEC { return m_elapsedmsec; }
+	/** テスト開始時刻 */
+	TimeInMillisec	start_timestamp(void)		const IUTEST_CXX_NOEXCEPT_SPEC{ return m_start_timestamp; }
 
 	/** TestInfo の取得 */
 	const TestInfo*	GetTestInfo(int index)		const { return m_testinfos[index]; }
@@ -117,10 +120,16 @@ public:
 	}
 
 	/** default package 名を含む TestCase 名の取得 */
-	::std::string testcase_name_with_default_package_name(void) const { return TestEnv::AddDefaultPackageName(name()); }
+	::std::string testcase_name_with_default_package_name(void) const
+	{
+		return TestEnv::AddDefaultPackageName(name());
+	}
 
 	/** テスト実行中じゃないときのリザルトの取得 */
-	const TestResult* ad_hoc_testresult(void) const IUTEST_CXX_NOEXCEPT_SPEC { return &m_ad_hoc_testresult; }
+	const TestResult* ad_hoc_testresult(void) const IUTEST_CXX_NOEXCEPT_SPEC
+	{
+		return &m_ad_hoc_testresult;
+	}
 
 public:
 	/**
@@ -226,6 +235,7 @@ private:
 	int				m_disable_num;		//!< 無視したテストの総数
 	int				m_should_run_num;	//!< 実行すべきテストの総数
 	TimeInMillisec	m_elapsedmsec;		//!< テスト時間
+	TimeInMillisec	m_start_timestamp;	//!< テスト開始時刻
 	bool			m_disable;			//!< 無効真偽値
 	TestResult		m_ad_hoc_testresult;	//!< テストが実行中でないときのリザルト
 
@@ -256,7 +266,10 @@ protected:
 
 public:
 	/** type param 文字列の取得 */
-	virtual const char* type_param(void) const IUTEST_CXX_OVERRIDE { return m_type_param.empty() ? NULL : m_type_param.c_str(); }
+	virtual const char* type_param(void) const IUTEST_CXX_OVERRIDE
+	{
+		return m_type_param.empty() ? NULL : m_type_param.c_str();
+	}
 
 private:
 	friend class UnitTestImpl;
@@ -273,7 +286,7 @@ namespace detail
 class TestCaseMediator IUTEST_CXX_FINAL : public detail::iuITestCaseMediator
 {
 public:
-	TestCaseMediator(TestCase* p) IUTEST_CXX_NOEXCEPT_SPEC : iuITestCaseMediator(p) {}
+	explicit TestCaseMediator(TestCase* p) IUTEST_CXX_NOEXCEPT_SPEC : iuITestCaseMediator(p) {}
 public:
 	virtual const char* test_case_name(void) const IUTEST_CXX_OVERRIDE { return m_test_case->name(); }
 	virtual const char* type_param(void)	 const IUTEST_CXX_OVERRIDE { return m_test_case->type_param(); }
