@@ -4,11 +4,9 @@
  * @file		iutest_env.hpp
  * @brief		iris unit test 環境 ファイル
  *
- * @author		t.sirayanagi
- * @version		1.0
- *
+ * @author		t.shirayanagi
  * @par			copyright
- * Copyright (C) 2011-2014, Takazumi Shirayanagi\n
+ * Copyright (C) 2011-2015, Takazumi Shirayanagi\n
  * This software is released under the new BSD License,
  * see LICENSE
 */
@@ -41,10 +39,15 @@
  *			print_time (bool)\n
  *          color (string)\n
  *          filter (string)\n
+ *          flagfile (string)\n
  *          output (string)\n
  *          repeat (int)\n
  *			list_tests (bool)\n
+ *			list_tests_with_where (bool)\n
+ *			verbose (bool)\n
  *			file_location_style_msvc (bool)\n
+ *			default_package_name (string)\n
+ *			ostream_formatter (ostream)\n
 */
 #define IUTEST_FLAG(name)	IIUT_FLAG(name)
 
@@ -58,6 +61,18 @@
  * @}
 */
 
+#if IUTEST_HAS_LIB && IUTEST_HAS_EXTERN_TEMPLATE
+
+namespace iutest { class Environment; }
+
+IUTEST_PRAGMA_EXTERN_TEMPLATE_WARN_DISABLE_BEGIN()
+
+extern template class ::std::vector< ::iutest::Environment* >;
+
+IUTEST_PRAGMA_EXTERN_TEMPLATE_WARN_DISABLE_END()
+
+#endif
+
 namespace iutest
 {
 
@@ -81,9 +96,14 @@ inline ::std::string EnvironmentString(const char* name)
 class Environment
 {
 public:
-	virtual ~Environment(void)	{}
+	virtual ~Environment(void)	{ Release(); }
 	virtual void SetUp(void)	{}	//!< 事前処理
 	virtual void TearDown(void)	{}	//!< 事後処理
+private:
+	void Release(void);
+private:
+	struct should_be_SetUp {};
+	virtual should_be_SetUp* Setup(void) IUTEST_CXX_FINAL { return NULL; }
 };
 
 /**
@@ -102,17 +122,17 @@ public:
 
 		int m_test_flags;
 	public:
-		ScopedGuard(void) 
+		ScopedGuard(void)
 		{
 			m_test_flags = TestFlag::GetInstance().m_test_flags;
 		}
-		~ScopedGuard(void) 
+		~ScopedGuard(void)
 		{
 			TestFlag::GetInstance().m_test_flags = m_test_flags;
 		}
 	};
 public:
-	/** 
+	/**
 	 * @brief	フラグ
 	*/
 	enum Kind
@@ -133,6 +153,7 @@ public:
 
 		PRINT_TIME				= 0x00001000,	//!< 経過時間の出力
 		FILELOCATION_STYLE_MSVC	= 0x00002000,	//!< ファイル/行出力スタイルを Visual Studio スタイルにする
+		VERBOSE					= 0x00004000,	//!< verbose
 
 		CATCH_EXCEPTION_EACH	= 0x00010000,	//!< 例外を catch する(TestInfo)
 		CATCH_EXCEPTION_GLOBAL	= 0x00020000,	//!< 例外を catch する(UnitTest)
@@ -145,6 +166,8 @@ public:
 		SHOW_HELP				= 0x10000000,	//!< ヘルプ表示
 		SHOW_VERSION			= 0x20000000,	//!< バージョン表示
 		SHOW_FEATURE			= 0x40000000,	//!< 機能の出力
+		SHOW_SPEC				= 0x80000000,	//!< Specの出力
+		SHOW_MASK				= 0xFF000000,	//!< 機能表示系マスク
 		MASK					= 0xFFFFFFFF,	//!< マスク
 
 		//! デフォルト
@@ -161,7 +184,7 @@ private:
 
 public:
 	/** @private */
-	static TestFlag&	GetInstance(void)	{ static TestFlag flag; return flag; }
+	static TestFlag& GetInstance(void) { static TestFlag flag; return flag; }
 public:
 	/**
 	 * @brief	フラグのビット操作
@@ -169,24 +192,28 @@ public:
 	 * @param [in]	enable	= 論理和
 	 * @param [in]	mask	= マスク値
 	*/
-	static void		SetFlag(int enable, int mask=-1)	{ GetInstance().m_test_flags |= enable; GetInstance().m_test_flags &= mask; }
+	static void SetFlag(int enable, int mask=-1)
+	{
+		GetInstance().m_test_flags |= enable;
+		GetInstance().m_test_flags &= mask;
+	}
 	/**
 	 * @brief	フラグが立っているかどうか
 	 * @param [in]	flag	= 検査対象フラグ
 	 * @return	真偽値
 	*/
-	static bool		IsEnableFlag(int flag)				{ return GetInstance().m_test_flags & flag ? true : false; }
+	static bool IsEnableFlag(int flag) { return GetInstance().m_test_flags & flag ? true : false; }
 
 private:
 	template<int KIND>
 	class Fragment
 	{
-		typedef Fragment<KIND>	_Myt;
+		typedef Fragment<KIND> _Myt;
 	public:
 		Fragment(void) IUTEST_CXX_NOEXCEPT_SPEC {}
-		Fragment(bool f)	{ SetFlag(KIND, f ? -1 : ~KIND); }
-		_Myt&	operator = (bool f)	{ SetFlag(KIND, f ? -1 : ~KIND); return *this; }
-		IUTEST_CXX_EXPLICIT_CONVERSION operator bool (void) const { return IsEnableFlag(KIND); }
+		Fragment(bool f) { SetFlag(KIND, f ? -1 : ~KIND); }	// NOLINT
+		_Myt& operator = (bool f) { SetFlag(KIND, f ? -1 : ~KIND); return *this; }
+		operator bool (void) const { return IsEnableFlag(KIND); }
 	};
 
 private:
@@ -206,7 +233,7 @@ class TestPartResultReporterInterface;
 */
 class TestEnv
 {
-	typedef ::std::vector<Environment*>	iuEnvironmentList;
+	typedef ::std::vector<Environment*> iuEnvironmentList;
 
 public:
 	/**
@@ -226,6 +253,7 @@ public:
 	typedef TestFlag::Fragment<TestFlag::CATCH_EXCEPTION_GLOBAL>	catch_exceptions_global;
 
 	typedef TestFlag::Fragment<TestFlag::FILELOCATION_STYLE_MSVC>	file_location_style_msvc;
+	typedef TestFlag::Fragment<TestFlag::VERBOSE>	verbose;
 
 	/**
 	 * @}
@@ -239,8 +267,8 @@ public:
 	{
 	public:
 		RandomSeedSet(void) IUTEST_CXX_NOEXCEPT_SPEC {}
-		RandomSeedSet(unsigned int seed) { init_random(seed); } 
-		RandomSeedSet&	operator = (unsigned int seed)	{ init_random(seed); return *this; }
+		RandomSeedSet(unsigned int seed) { init_random(seed); }
+		RandomSeedSet& operator = (unsigned int seed) { init_random(seed); return *this; }
 		operator unsigned int (void) const { return get_random_seed(); }
 	} random_seed;
 
@@ -252,8 +280,8 @@ public:
 	{
 	public:
 		RepeatCountSet(void) IUTEST_CXX_NOEXCEPT_SPEC {}
-		RepeatCountSet(int count) { set_repeat_count(count); } 
-		RepeatCountSet&	operator = (int count)	{ set_repeat_count(count); return *this; }
+		RepeatCountSet(int count) { set_repeat_count(count); }
+		RepeatCountSet& operator = (int count) { set_repeat_count(count); return *this; }
 		operator int (void) const { return get_repeat_count(); }
 	} repeat;
 
@@ -278,46 +306,65 @@ private:
 		int					m_repeat_count;
 		::std::string		m_output_option;
 		::std::string		m_test_filter;
+		::std::string		m_flagfile;
 #if IUTEST_HAS_STREAM_RESULT
 		::std::string		m_stream_result_to;
 #endif
+		::std::string		m_default_package_name;
 		detail::iuRandom	m_genrand;
 		iuEnvironmentList	m_environment_list;
 		TestEventListeners	m_event_listeners;
 		TestPartResultReporterInterface*	m_testpartresult_reporter;
+#if IUTEST_HAS_STRINGSTREAM || IUTEST_HAS_STRSTREAM
+		iu_stringstream		m_ostream_formatter;
+#endif
 	};
 
 	static Variable& get_vars(void) { static Variable v; return v; }
 
 public:
-
 	static detail::iuRandom&	genrand(void)				{ return get_vars().m_genrand; }				//!< 乱数生成器
 	static unsigned int			get_random_seed(void)		{ return get_vars().m_random_seed; }			//!< 乱数シード
 	static unsigned int			current_random_seed(void)	{ return get_vars().m_current_random_seed; }	//!< 乱数シード
 	static int					get_repeat_count(void)		{ return get_vars().m_repeat_count; }			//!< 繰り返し回数
 	static const char*			get_output_option(void)		{ return get_vars().m_output_option.c_str(); }	//!< 出力オプション
+	static const char*			get_default_package_name(void) { return get_vars().m_default_package_name.c_str(); }	//!< root package オプション
 	static const char*			test_filter(void)			{ return get_vars().m_test_filter.c_str(); }	//!< フィルター文字列
+	static const char*			get_flagfile(void)			{ return get_vars().m_flagfile.c_str(); }		//!< flag file
 #if IUTEST_HAS_STREAM_RESULT
 	static const char*			get_stream_result_to(void)	{ return get_vars().m_stream_result_to.c_str(); }
 #endif
+#if IUTEST_HAS_STRINGSTREAM || IUTEST_HAS_STRSTREAM
+	static void					global_ostream_copyfmt(iu_ostream& os) { os.copyfmt(get_vars().m_ostream_formatter); }	// NOLINT
+#endif
 
 	/**
-	* @brief	xml 出力パスを取得
+	 * @brief	xml 出力パスを取得
 	*/
 	static ::std::string get_report_xml_filepath(void);
+	/**
+	 * @brief	junit xml 出力パスを取得
+	*/
+	static ::std::string get_report_junit_xml_filepath(void);
 
 	/** @private */
-	static TestEventListeners&	event_listeners(void)	{ return get_vars().m_event_listeners; }
+	static TestEventListeners& event_listeners(void) { return get_vars().m_event_listeners; }
 	/** @private */
-	static TestPartResultReporterInterface* GetGlobalTestPartResultReporter(void)		{ return get_vars().m_testpartresult_reporter; }
+	static TestPartResultReporterInterface* GetGlobalTestPartResultReporter(void)
+	{
+		return get_vars().m_testpartresult_reporter;
+	}
 	/** @private */
-	static void SetGlobalTestPartResultReporter(TestPartResultReporterInterface* ptr)	{ get_vars().m_testpartresult_reporter = ptr; }
+	static void SetGlobalTestPartResultReporter(TestPartResultReporterInterface* ptr)
+	{
+		get_vars().m_testpartresult_reporter = ptr;
+	}
 
 private:
 	/**
 	 * @brief	乱数シードの設定
 	*/
-	static void	init_random(unsigned int seed)
+	static void init_random(unsigned int seed)
 	{
 		get_vars().m_random_seed = seed;
 	}
@@ -325,7 +372,7 @@ private:
 	/**
 	 * @brief	繰り返し回数の設定
 	*/
-	static void	set_repeat_count(int count)
+	static void set_repeat_count(int count)
 	{
 		get_vars().m_repeat_count = count;
 	}
@@ -333,16 +380,34 @@ private:
 	/**
 	 * @brief	フィルター文字列の設定
 	*/
-	static void	set_test_filter(const char* str)
+	static void set_test_filter(const char* str)
 	{
 		get_vars().m_test_filter = str == NULL ? "*" : str;
 		TestFlag::SetFlag(TestFlag::FILTERING_TESTS);
 	}
+
+	/**
+	 * @brief	flagfile の設定
+	*/
+	static void set_flagfile_path(const char* str)
+	{
+		get_vars().m_flagfile = str;
+	}
+
+	/**
+	 * @brief	flagfile の設定
+	*/
+	static void set_flagfile(const char* str)
+	{
+		ParseFlagFileOption(str);
+		LoadFlagFile();
+	}
+
 #if IUTEST_HAS_STREAM_RESULT
 	/**
 	 * @brief	stream result の設定
 	*/
-	static void	set_stream_result_to(const char* str)
+	static void set_stream_result_to(const char* str)
 	{
 		get_vars().m_stream_result_to = str == NULL ? "" : str;
 	}
@@ -353,17 +418,17 @@ private:
 	*/
 	static const char* get_color_option(void)
 	{
-		if( TestFlag::IsEnableFlag(TestFlag::CONSOLE_COLOR_OFF) )
+		if( TestFlag::IsEnableFlag(TestFlag::CONSOLE_COLOR_ANSI) )
 		{
-			return "no";
+			return "ansi";
 		}
 		else if( TestFlag::IsEnableFlag(TestFlag::CONSOLE_COLOR_ON) )
 		{
 			return "yes";
 		}
-		else if( TestFlag::IsEnableFlag(TestFlag::CONSOLE_COLOR_ANSI) )
+		else if( TestFlag::IsEnableFlag(TestFlag::CONSOLE_COLOR_OFF) )
 		{
-			return "ansi";
+			return "no";
 		}
 		return "auto";
 	}
@@ -383,6 +448,14 @@ private:
 		get_vars().m_output_option = str == NULL ? "" : str;
 	}
 
+	/**
+	 * @brief	default_package_name オプションを設定
+	*/
+	static void set_default_package_name(const char* str)
+	{
+		get_vars().m_default_package_name = str == NULL ? "" : str;
+	}
+
 private:
 	typedef const char* (*pfnOptionStringGet)();
 	typedef void(*pfnOptionStringSet)(const char*);
@@ -390,19 +463,24 @@ private:
 	class OptionString
 	{
 		typedef OptionString<G, S> _Myt;
+		typedef const _Myt& _Argt;
 	protected:
-		::std::string	m_option;
+		::std::string m_option;
 	public:
-		bool operator == (const char* c_str_)		{ return m_option == c_str_; }
-		bool operator == (const ::std::string& str)	{ return m_option == str; }
-		bool operator != (const char* c_str_)		{ return m_option != c_str_; }
-		bool operator != (const ::std::string& str)	{ return m_option != str; }
+		friend bool operator == (const char* c_str_, _Argt rhs)			{ return rhs.m_option == c_str_; }
+		friend bool operator == (const ::std::string& str, _Argt rhs)	{ return rhs.m_option == str; }
+		friend bool operator == (_Argt lhs, const char* c_str_)			{ return lhs.m_option == c_str_; }
+		friend bool operator == (_Argt lhs, const ::std::string& str)	{ return lhs.m_option == str; }
+		friend bool operator != (const char* c_str_, _Argt rhs)			{ return rhs.m_option != c_str_; }
+		friend bool operator != (const ::std::string& str, _Argt rhs)	{ return rhs.m_option != str; }
+		friend bool operator != (_Argt lhs, const char* c_str_)			{ return lhs.m_option != c_str_; }
+		friend bool operator != (_Argt lhs, const ::std::string& str)	{ return lhs.m_option != str; }
 
-		operator ::std::string (void) const	{ return m_option; }
+		operator ::std::string (void) const { return m_option; }
 	public:
 		bool empty(void) const			{ return m_option.empty(); }
 		const char* c_str(void) const	{ return m_option.c_str(); }
-		size_t	length(void) const		{ return m_option.length(); }
+		size_t length(void) const		{ return m_option.length(); }
 	public:
 		OptionString(void)
 			: m_option(G())
@@ -421,6 +499,7 @@ private:
 			return *this;
 		}
 	};
+
 public:
 	/**
 	 * @private
@@ -435,8 +514,14 @@ public:
 	typedef OptionString<test_filter, set_test_filter> filter;
 
 	/**
-	* @private
-	* @brief	出力オプション設定用オブジェクト
+	 * @private
+	 * @brief	フィルターオプション設定用オブジェクト
+	*/
+	typedef OptionString<get_flagfile, set_flagfile> flagfile;
+
+	/**
+	 * @private
+	 * @brief	出力オプション設定用オブジェクト
 	*/
 	typedef OptionString<get_output_option, set_output_option> output;
 
@@ -446,10 +531,41 @@ public:
 	 * @brief	stream resultオプション設定用オブジェクト
 	*/
 	typedef OptionString<get_stream_result_to, set_stream_result_to> stream_result_to;
+#endif
+
+	/**
+	 * @private
+	 * @brief	default_package_name オプション設定用オブジェクト
+	*/
+	typedef OptionString<get_default_package_name, set_default_package_name> default_package_name;
+
+#if IUTEST_HAS_STRINGSTREAM || IUTEST_HAS_STRSTREAM
+	/**
+	 * @private
+	 * @brief	ostream_formatter オプション設定用オブジェクト
+	*/
+	typedef class OStreamFormatter : public iu_stringstream
+	{
+		IUTEST_WORKAROUND_MSC_STLSTREAM_C4250()
+	public:
+		OStreamFormatter(void)
+		{
+			copyfmt(get_vars().m_ostream_formatter);
+		}
+		virtual ~OStreamFormatter(void)
+		{
+			get_vars().m_ostream_formatter.copyfmt(*this);
+		}
+	} ostream_formatter;
+
+#if defined(IUTEST_NO_PRIVATE_IN_AGGREGATE)
+	friend class OStreamFormatter;
+#endif
+
 #endif
 
 private:
-	static iuEnvironmentList&	environments(void)		{ return get_vars().m_environment_list; }
+	static iuEnvironmentList& environments(void) { return get_vars().m_environment_list; }
 
 public:
 	/**
@@ -467,6 +583,29 @@ public:
 		return env;
 	}
 
+	/**
+	 * @brief	グローバル環境セットクラスの削除
+	 * @param [in]	env	= 環境セットクラスアドレス
+	 * @return	削除されたクラスアドレス
+	*/
+	static Environment* ReleaseGlobalTestEnvironment(Environment* env)
+	{
+		if( env == NULL )
+		{
+			return NULL;
+		}
+		iuEnvironmentList& list = environments();
+		iuEnvironmentList::iterator it = ::std::find(list.begin(), list.end(), env);
+		if( it == list.end() ) return NULL;
+		list.erase(it);
+		return env;
+	}
+
+	/**
+	 * @brief	default package name を追加
+	*/
+	static ::std::string AddDefaultPackageName(const char* testcase_name);
+
 private:
 	/**
 	 * @brief	環境セットクラスの解放
@@ -488,8 +627,9 @@ public:
 	 * @brief	コマンドライン引数の解析
 	*/
 	template<typename CharType>
-	static void	ParseCommandLine(int* pargc, CharType** argv)
+	static void ParseCommandLine(int* pargc, CharType** argv)
 	{
+		if( argv == NULL ) return;
 		int argc = *pargc;
 
 		for( int i=0; i < argc; )
@@ -518,9 +658,10 @@ public:
 	 * @brief	コマンドライン引数の解析(vector)
 	*/
 	template<typename CharType>
-	static void	ParseCommandLine(::std::vector< ::std::basic_string<CharType> >& argv)
+	static void ParseCommandLine(::std::vector< ::std::basic_string<CharType> >& argv)
 	{
-		for( typename ::std::vector< ::std::basic_string<CharType> >::iterator it = argv.begin(); it != argv.end(); )
+		typedef ::std::vector< ::std::basic_string<CharType> > argv_t;
+		for( typename argv_t::iterator it = argv.begin(); it != argv.end(); )
 		{
 			if( ParseCommandLineElem(it->c_str()) )
 			{
@@ -532,9 +673,13 @@ public:
 			}
 		}
 	}
+
+	/** @brief	フラグファイルをロード */
+	static bool LoadFlagFile(void);
+
 private:
 	template<typename CharType>
-	static bool	ParseCommandLineElem(CharType* argv)
+	static bool ParseCommandLineElem(CharType* argv)
 	{
 		typedef typename detail::mbs_ptr<CharType> formatter;
 
@@ -553,7 +698,7 @@ private:
 	/**
 	 * @brief	セットアップ
 	*/
-	static void	SetUp(void);
+	static void SetUp(void);
 
 private:
 	/**
@@ -564,24 +709,34 @@ private:
 		const char* eq = strchr(opt, '=');
 		if( eq == NULL )
 		{
-			return eq;
+			return NULL;
 		}
 		return eq+1;
 	}
 	/**
 	 * @brief	IUTEST_COLOR オプションの判定
 	*/
-	static bool	ParseColorOption(const char* option);
+	static bool ParseColorOption(const char* option);
 
 	/**
 	 * @brief	IUTEST_OUTPUT オプションの判定
 	*/
-	static bool	ParseOutputOption(const char* option);
+	static bool ParseOutputOption(const char* option);
 
 	/**
 	 * @brief	IUTEST_FILE_LOCATION オプションの判定
 	*/
-	static bool	ParseFileLocationOption(const char* option);
+	static bool ParseFileLocationOption(const char* option);
+
+	/**
+	 * @brief	IUTEST_FILTER オプションの判定
+	*/
+	static bool ParseFilterOption(const char* option);
+
+	/**
+	 * @brief	IUTEST_FLAGFILE オプションの判定
+	*/
+	static bool ParseFlagFileOption(const char* option);
 
 	/**
 	 * @brief	yes オプションか no オプションかの判定
@@ -614,10 +769,39 @@ private:
 	friend class UnitTest;
 };
 
+/**
+ * @brief	ostream_formatter オプションが適用されてた stringstream
+*/
+class iu_global_format_stringstream : public iu_stringstream
+{
+	IUTEST_WORKAROUND_MSC_STLSTREAM_C4250()
+public:
+	iu_global_format_stringstream()
+	{
+#if IUTEST_HAS_STRINGSTREAM || IUTEST_HAS_STRSTREAM
+		TestEnv::global_ostream_copyfmt(*this);
+#endif
+	}
+	explicit iu_global_format_stringstream(const char* str)
+		: iu_stringstream(str)
+	{
+#if IUTEST_HAS_STRINGSTREAM || IUTEST_HAS_STRSTREAM
+		TestEnv::global_ostream_copyfmt(*this);
+#endif
+	}
+	explicit iu_global_format_stringstream(const ::std::string& str)
+		: iu_stringstream(str)
+	{
+#if IUTEST_HAS_STRINGSTREAM || IUTEST_HAS_STRSTREAM
+		TestEnv::global_ostream_copyfmt(*this);
+#endif
+	}
+};
+
 }	// end of namespace iutest
 
 #if !IUTEST_HAS_LIB
 #  include "impl/iutest_env.ipp"
 #endif
 
-#endif	// INCG_IRIS_IUTEST_ENV_HPP_F4017EAB_6CA3_4E6E_8983_059393DADD04_
+#endif // INCG_IRIS_IUTEST_ENV_HPP_F4017EAB_6CA3_4E6E_8983_059393DADD04_
