@@ -6,7 +6,7 @@
  *
  * @author		t.shirayanagi
  * @par			copyright
- * Copyright (C) 2011-2014, Takazumi Shirayanagi\n
+ * Copyright (C) 2011-2015, Takazumi Shirayanagi\n
  * This software is released under the new BSD License,
  * see LICENSE
 */
@@ -556,8 +556,8 @@
 
 
 /**
-* @private
-* @{
+ * @private
+ * @{
 */
 
 #define IUTEST_PRED1_(pred, v1, on_failure)	\
@@ -607,7 +607,7 @@
 	IUTEST_TEST_THROW_VALUE_(statement, expected_exception, expected_exception_value, on_failure, pred_formatter)
 
 /**
-* @}
+ * @}
 */
 
 namespace iutest
@@ -618,20 +618,20 @@ namespace iutest
 /** @private */
 template<typename PRED, typename T1>
 AssertionResult AssertPred1Helper(const char* pred_str, const char* expr1
-							, PRED pred, T1 val1)
+	, PRED pred, T1 val1)
 {
 	if( (*pred)(val1) )
 	{
 		return AssertionSuccess();
 	}
 	return AssertionFailure() << "error: " << pred_str << "(" << expr1 << ") evaluates to false, where "
-		<< "\n" << expr1 << " : " << val1 ;
+		<< "\n" << expr1 << " : " << val1;
 }
 
 /** @private */
 template<typename PRED, typename T1, typename T2>
 AssertionResult AssertPred2Helper(const char* pred_str, const char* expr1, const char* expr2
-							, PRED pred, T1 val1, T2 val2)
+	, PRED pred, T1 val1, T2 val2)
 {
 	if( (*pred)(val1, val2) )
 	{
@@ -641,13 +641,14 @@ AssertionResult AssertPred2Helper(const char* pred_str, const char* expr1, const
 		<< expr1 << ", " << expr2
 		<< ") evaluates to false, where "
 		<< "\n" << expr1 << " : " << val1
-		<< "\n" << expr2 << " : " << val2 ;
+		<< "\n" << expr2 << " : " << val2;
 }
 
 /** @private */
 template<typename PRED, typename T1, typename T2, typename T3>
-AssertionResult AssertPred3Helper(const char* pred_str, const char* expr1, const char* expr2, const char* expr3
-							, PRED pred, T1 val1, T2 val2, T3 val3)
+AssertionResult AssertPred3Helper(const char* pred_str
+	, const char* expr1, const char* expr2, const char* expr3
+	, PRED pred, T1 val1, T2 val2, T3 val3)
 {
 	if( (*pred)(val1, val2, val3) )
 	{
@@ -658,13 +659,14 @@ AssertionResult AssertPred3Helper(const char* pred_str, const char* expr1, const
 		<< ") evaluates to false, where "
 		<< "\n" << expr1 << " : " << val1
 		<< "\n" << expr2 << " : " << val2
-		<< "\n" << expr3 << " : " << val3 ;
+		<< "\n" << expr3 << " : " << val3;
 }
 
 /** @private */
 template<typename PRED, typename T1, typename T2, typename T3, typename T4>
-AssertionResult AssertPred4Helper(const char* pred_str, const char* expr1, const char* expr2, const char* expr3, const char* expr4
-							, PRED pred, T1 val1, T2 val2, T3 val3, T4 val4)
+AssertionResult AssertPred4Helper(const char* pred_str
+	, const char* expr1, const char* expr2, const char* expr3, const char* expr4
+	, PRED pred, T1 val1, T2 val2, T3 val3, T4 val4)
 {
 	if( (*pred)(val1, val2, val3, val4) )
 	{
@@ -676,13 +678,14 @@ AssertionResult AssertPred4Helper(const char* pred_str, const char* expr1, const
 		<< "\n" << expr1 << " : " << val1
 		<< "\n" << expr2 << " : " << val2
 		<< "\n" << expr3 << " : " << val3
-		<< "\n" << expr4 << " : " << val4 ;
+		<< "\n" << expr4 << " : " << val4;
 }
 
 /** @private */
 template<typename PRED, typename T1, typename T2, typename T3, typename T4, typename T5>
-AssertionResult AssertPred5Helper(const char* pred_str, const char* expr1, const char* expr2, const char* expr3, const char* expr4, const char* expr5
-							, PRED pred, T1 val1, T2 val2, T3 val3, T4 val4, T5 val5)
+AssertionResult AssertPred5Helper(const char* pred_str
+	, const char* expr1, const char* expr2, const char* expr3, const char* expr4, const char* expr5
+	, PRED pred, T1 val1, T2 val2, T3 val3, T4 val4, T5 val5)
 {
 	if( (*pred)(val1, val2, val3, val4, val5) )
 	{
@@ -695,14 +698,15 @@ AssertionResult AssertPred5Helper(const char* pred_str, const char* expr1, const
 		<< "\n" << expr2 << " : " << val2
 		<< "\n" << expr3 << " : " << val3
 		<< "\n" << expr4 << " : " << val4
-		<< "\n" << expr5 << " : " << val5 ;
+		<< "\n" << expr5 << " : " << val5;
 }
 
 #if IUTEST_HAS_VARIADIC_TEMPLATES
 
 /** @private */
 template<typename PRED, typename ...Args>
-AssertionResult AssertPredVariadicHelper(const char* pred_str, const char* params, PRED pred, Args... args)
+AssertionResult AssertPredVariadicHelper(const char* pred_str, const char* params
+	, PRED pred, Args... args)
 {
 	if( (*pred)(args...) )
 	{
