@@ -34,25 +34,29 @@
  * @ingroup	IUTEST_ASSERT_
  * @brief	Fatal Failure 発生確認テスト
 */
-#define IUTEST_ASSERT_FATAL_FAILURE(statement, substr)		IUTEST_TEST_FATAL_FAILURE_(statement, #statement, substr, IUTEST_ASSERT_FAILURE)
+#define IUTEST_ASSERT_FATAL_FAILURE(statement, substr)		\
+	IUTEST_TEST_FATAL_FAILURE_(statement, #statement, substr, IUTEST_ASSERT_FAILURE)
 
 /**
  * @ingroup	IUTEST_ASSERT_
  * @brief	Non Fatal Failure 発生確認テスト
 */
-#define IUTEST_ASSERT_NONFATAL_FAILURE(statement, substr)	IUTEST_TEST_NONFATAL_FAILURE_(statement, #statement, substr, IUTEST_ASSERT_FAILURE)
+#define IUTEST_ASSERT_NONFATAL_FAILURE(statement, substr)	\
+	IUTEST_TEST_NONFATAL_FAILURE_(statement, #statement, substr, IUTEST_ASSERT_FAILURE)
 
 /**
  * @ingroup	IUTEST_EXPECT_
  * @brief	Fatal Failure 発生確認テスト
 */
-#define IUTEST_EXPECT_FATAL_FAILURE(statement, substr)		IUTEST_TEST_FATAL_FAILURE_(statement, #statement, substr, IUTEST_EXPECT_FAILURE)
+#define IUTEST_EXPECT_FATAL_FAILURE(statement, substr)		\
+	IUTEST_TEST_FATAL_FAILURE_(statement, #statement, substr, IUTEST_EXPECT_FAILURE)
 
 /**
  * @ingroup	IUTEST_EXPECT_
  * @brief	Non Fatal Failure 発生確認テスト
 */
-#define IUTEST_EXPECT_NONFATAL_FAILURE(statement, substr)	IUTEST_TEST_NONFATAL_FAILURE_(statement, #statement, substr, IUTEST_EXPECT_FAILURE)
+#define IUTEST_EXPECT_NONFATAL_FAILURE(statement, substr)	\
+	IUTEST_TEST_NONFATAL_FAILURE_(statement, #statement, substr, IUTEST_EXPECT_FAILURE)
 
 
 /**
@@ -63,81 +67,84 @@
 #if IUTEST_HAS_SPI_LAMBDA_SUPPORT
 
 #if IUTEST_HAS_EXCEPTIONS && IUTEST_USE_THROW_ON_ASSERTION_FAILURE
-#  define IIUT_STATEMENT_EXECUTER(statement)	[&](){ try {	\
+#  define IIUT_SPI_STATEMENT_EXECUTER(statement) [&](){ try {	\
 	::iutest::detail::ScopedSPITestFlag guard;					\
 	statement;													\
 	} catch(...) {}												\
 	}()
 #else
-#  define IIUT_STATEMENT_EXECUTER(statement)	[&](){ ::iutest::detail::ScopedSPITestFlag guard; statement; }()
+#  define IIUT_SPI_STATEMENT_EXECUTER(statement)	\
+	[&](){ ::iutest::detail::ScopedSPITestFlag guard; statement; }()
 #endif
 
-#define IUTEST_TEST_FATAL_FAILURE_(statement, text, substr, on_failure)				\
-	if( ::iutest::AssertionResult iutest_ar = [&]() -> ::iutest::AssertionResult {	\
-		::iutest::detail::SPIFailureChecker<										\
-			::iutest::TestPartResult::kFatalFailure> iutest_failure_checker;		\
-		IIUT_STATEMENT_EXECUTER(statement);											\
-		return iutest_failure_checker.GetResult(substr);							\
-	}() )																			\
-		;																			\
-	else																			\
-		on_failure(iutest_ar.message())
+#define IUTEST_TEST_FATAL_FAILURE_(statement, text, substr, on_failure)					\
+	IUTEST_AMBIGUOUS_ELSE_BLOCKER_														\
+	if( ::iutest::AssertionResult iutest_spi_ar = [&]() -> ::iutest::AssertionResult {	\
+		::iutest::detail::SPIFailureChecker<											\
+			::iutest::TestPartResult::kFatalFailure> iutest_failure_checker;			\
+		IIUT_SPI_STATEMENT_EXECUTER(statement);											\
+		return iutest_failure_checker.GetResult(substr);								\
+	}() )																				\
+		;																				\
+	else																				\
+		on_failure(iutest_spi_ar.message())
 
-#define IUTEST_TEST_NONFATAL_FAILURE_(statement, text, substr, on_failure)			\
-	if( ::iutest::AssertionResult iutest_ar = [&]() -> ::iutest::AssertionResult {	\
-		::iutest::detail::SPIFailureChecker<										\
-			::iutest::TestPartResult::kNonFatalFailure> iutest_failure_checker;		\
-		IIUT_STATEMENT_EXECUTER(statement);											\
-		return iutest_failure_checker.GetResult(substr);							\
-	}() )																			\
-		;																			\
-	else																			\
-		on_failure(iutest_ar.message())
+#define IUTEST_TEST_NONFATAL_FAILURE_(statement, text, substr, on_failure)				\
+	IUTEST_AMBIGUOUS_ELSE_BLOCKER_														\
+	if( ::iutest::AssertionResult iutest_spi_ar = [&]() -> ::iutest::AssertionResult {	\
+		::iutest::detail::SPIFailureChecker<											\
+			::iutest::TestPartResult::kNonFatalFailure> iutest_failure_checker;			\
+		IIUT_SPI_STATEMENT_EXECUTER(statement);											\
+		return iutest_failure_checker.GetResult(substr);								\
+	}() )																				\
+		;																				\
+	else																				\
+		on_failure(iutest_spi_ar.message())
 
 #else
 
 #if IUTEST_HAS_EXCEPTIONS && IUTEST_USE_THROW_ON_ASSERTION_FAILURE
-#  define IIUT_STATEMENT_EXECUTER(statement)	struct IUTestFatalFailureStatement {	\
+#  define IIUT_SPI_STATEMENT_EXECUTER(statement) struct IUTestFatalFailureStatement {	\
 	static void Execute() { ::iutest::detail::ScopedSPITestFlag guard;					\
 	try { statement; } catch(...) {} }													\
 	};																					\
 	IUTestFatalFailureStatement::Execute()
 #else
-#  define IIUT_STATEMENT_EXECUTER(statement)	struct IUTestFatalFailureStatement {	\
+#  define IIUT_SPI_STATEMENT_EXECUTER(statement) struct IUTestFatalFailureStatement {	\
 	static void Execute() { ::iutest::detail::ScopedSPITestFlag guard; statement; }		\
 	};																					\
 	IUTestFatalFailureStatement::Execute()
 #endif
 
-#define IUTEST_TEST_FATAL_FAILURE_(statement, text, substr, on_failure)			\
-	IUTEST_AMBIGUOUS_ELSE_BLOCKER_												\
-	if( ::iutest::AssertionResult iutest_ar = ::iutest::AssertionSuccess() ) {	\
-		::iutest::detail::SPIFailureChecker<									\
-			::iutest::TestPartResult::kFatalFailure> iutest_failure_checker;	\
-		IIUT_STATEMENT_EXECUTER(statement);										\
-		::iutest::AssertionResult ar = iutest_failure_checker.GetResult(substr);\
-		if( !ar ) {																\
-			iutest_ar << ar.message();											\
-			goto IUTEST_PP_CAT(iutest_label_test_fatalfailure_, __LINE__);		\
-		}																		\
-	} else																		\
-		IUTEST_PP_CAT(iutest_label_test_fatalfailure_, __LINE__):				\
-		on_failure(iutest_ar.message())
+#define IUTEST_TEST_FATAL_FAILURE_(statement, text, substr, on_failure)				\
+	IUTEST_AMBIGUOUS_ELSE_BLOCKER_													\
+	if( ::iutest::AssertionResult iutest_spi_ar = ::iutest::AssertionSuccess() ) {	\
+		::iutest::detail::SPIFailureChecker<										\
+			::iutest::TestPartResult::kFatalFailure> iutest_failure_checker;		\
+		IIUT_SPI_STATEMENT_EXECUTER(statement);										\
+		::iutest::AssertionResult ar = iutest_failure_checker.GetResult(substr);	\
+		if( !ar ) {																	\
+			iutest_spi_ar << ar.message();											\
+			goto IUTEST_PP_CAT(iutest_label_test_fatalfailure_, __LINE__);			\
+		}																			\
+	} else																			\
+		IUTEST_PP_CAT(iutest_label_test_fatalfailure_, __LINE__):					\
+		on_failure(iutest_spi_ar.message())
 
-#define IUTEST_TEST_NONFATAL_FAILURE_(statement, text, substr, on_failure)		\
-	IUTEST_AMBIGUOUS_ELSE_BLOCKER_												\
-	if( ::iutest::AssertionResult iutest_ar = ::iutest::AssertionSuccess() ) {	\
-		::iutest::detail::SPIFailureChecker<									\
-			::iutest::TestPartResult::kNonFatalFailure> iutest_failure_checker;	\
-		IIUT_STATEMENT_EXECUTER(statement);										\
-		::iutest::AssertionResult ar = iutest_failure_checker.GetResult(substr);\
-		if( !ar ) {																\
-			iutest_ar << ar.message();											\
-			goto IUTEST_PP_CAT(iutest_label_test_fatalfailure_, __LINE__);		\
-		}																		\
-	} else																		\
-		IUTEST_PP_CAT(iutest_label_test_fatalfailure_, __LINE__):				\
-		on_failure(iutest_ar.message())
+#define IUTEST_TEST_NONFATAL_FAILURE_(statement, text, substr, on_failure)			\
+	IUTEST_AMBIGUOUS_ELSE_BLOCKER_													\
+	if( ::iutest::AssertionResult iutest_spi_ar = ::iutest::AssertionSuccess() ) {	\
+		::iutest::detail::SPIFailureChecker<										\
+			::iutest::TestPartResult::kNonFatalFailure> iutest_failure_checker;		\
+		IIUT_SPI_STATEMENT_EXECUTER(statement);										\
+		::iutest::AssertionResult ar = iutest_failure_checker.GetResult(substr);	\
+		if( !ar ) {																	\
+			iutest_spi_ar << ar.message();											\
+			goto IUTEST_PP_CAT(iutest_label_test_fatalfailure_, __LINE__);			\
+		}																			\
+	} else																			\
+		IUTEST_PP_CAT(iutest_label_test_fatalfailure_, __LINE__):					\
+		on_failure(iutest_spi_ar.message())
 
 //		IUTEST_SUPPRESS_UNREACHABLE_CODE_WARNING(statement);
 
@@ -153,30 +160,19 @@ namespace detail
 
 //======================================================================
 // class
-/**
- * @brief	SPI 用リポーター
-*/
-class FakeTestPartResultReporter : public TestPartResultReporterInterface
-{
-public:
-	virtual ~FakeTestPartResultReporter(void) {}
-	virtual void ReportTestPartResult(const TestPartResult& result) IUTEST_CXX_OVERRIDE
-	{
-		IUTEST_UNUSED_VAR(result);
-	}
-};
 
 /**
  * @brief	SPI チェッカー
 */
 template<TestPartResult::Type Type>
 class SPIFailureChecker
-	: public NewTestPartResultCheckHelper::Collector<FakeTestPartResultReporter>
+	: public NewTestPartResultCheckHelper::Collector<NoTestPartResultReporter>
 {
 public:
 	AssertionResult GetResult(const ::std::string& substr)
 	{
-		const char* expected = Type == TestPartResult::kFatalFailure ? "1 fatal failure" : "1 non-fatal failure";
+		const char* expected =
+			(Type == TestPartResult::kFatalFailure) ? "1 fatal failure" : "1 non-fatal failure";
 		const size_t num = count();
 		if( num != 1 )
 		{
