@@ -17,9 +17,9 @@
 
 //======================================================================
 // define
-#define IUTEST_VER			0x01130000u //!< iutest version 1.13.0.0
+#define IUTEST_VER			0x01140000u //!< iutest version 1.14.0.0
 #define IUTEST_MAJORVER		0x01u		//!< Major Version
-#define IUTEST_MINORVER		0x13u		//!< Minor Version
+#define IUTEST_MINORVER		0x14u		//!< Minor Version
 #define IUTEST_BUILD		0x00u		//!< Build
 #define IUTEST_REVISION		0x00u		//!< Revision
 
@@ -36,29 +36,30 @@
  *
  * @par		LICENSE
 
-Redistribution and use in source and binary forms, with or without modification,
-are permitted provided that the following conditions are met:\n
-\n
-  1. Redistributions of source code must retain the above copyright notice,\n
-     this list of conditions and the following disclaimer.\n
-  2. Redistributions in binary form must reproduce the above copyright notice,\n
-     this list of conditions and the following disclaimer in the documentation \n
-     and/or other materials provided with the distribution.\n
-  3. the copyright holder's name is not used to endorse products \n
-     built using this software without specific written permission.\n
-\n
-THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
-"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
-LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A 
-PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT 
-HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, 
-SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT 
-LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, 
-DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY 
-THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT 
-(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE 
-OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-
+ Redistribution and use in source and binary forms, with or without
+ modification, are permitted provided that the following conditions are met:\n
+ \n
+ * Redistributions of source code must retain the above copyright notice, this
+ list of conditions and the following disclaimer.\n
+ \n
+ * Redistributions in binary form must reproduce the above copyright notice,
+ this list of conditions and the following disclaimer in the documentation
+ and/or other materials provided with the distribution.\n
+ \n
+ * Neither the name of iutest nor the names of its
+ contributors may be used to endorse or promote products derived from
+ this software without specific prior written permission.\n
+ \n
+ THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
+ AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
+ DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
+ FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
+ DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
+ SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
+ CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
+ OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
+ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
 
 /**
@@ -115,6 +116,12 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  * @page	CHANGELOG	変更履歴
  * @par		Changes
  <ul>
+  <li>v1.14.0.0
+    <ul>
+      <li>::iutest::Range を Enum に対応</li>
+      <li>大幅なリファクタリング</li>
+    </ul>
+  </li>
   <li>v1.13.0.0
     <ul>
       <li>--iutest_flagfile コマンドラインオプションに対応</li>
