@@ -6,7 +6,7 @@
  *
  * @author		t.shirayanagi
  * @par			copyright
- * Copyright (C) 2014, Takazumi Shirayanagi\n
+ * Copyright (C) 2014-2015, Takazumi Shirayanagi\n
  * This software is released under the new BSD License,
  * see LICENSE
 */
@@ -275,9 +275,28 @@ IUTEST(StaticTest, Eq)
 
 #endif
 
+#if IUTEST_HAS_REGEX
+
+IUTEST(AssertionTest, Regex)
+{
+	const char test [] = "te0123st";
+	IUTEST_ASSERT_MATCHES_REGEXEQ("te[0-9]*st", test);
+}
+
+#endif
+
+
 /* ---------------------------------------------------
  * 失敗の確認
 *//*--------------------------------------------------*/
+IUTEST(DISABLED_TestFailure, Expression)
+{
+	IUTEST_EXPECT(f() > f() + 1 );
+	IUTEST_EXPECT_NOT(f() == 42);
+	IUTEST_EXPECT(f() && 0);
+	IUTEST_EXPECT(true && false);
+}
+
 IUTEST(DISABLED_TestFailure, EQ)
 {
 	IUTEST_ASSERT_EQ(0, 1);
