@@ -680,3 +680,16 @@ IUTEST(SyntaxTest, ExceptionVectorConstructor)
 
 #endif
 
+#if !defined(IUTEST_USE_GTEST) && defined(__WANDBOX__)
+
+IUTEST(SyntaxTest, ShowFeature)
+{
+	::iutest::detail::iuOptionMessage::ShowFeature();
+}
+IUTEST(SyntaxTest, ShowSpec)
+{
+	::iutest::detail::iuOptionMessage::ShowSpec();
+}
+
+#endif
+
